summary | shortlog | log | commit | commitdiff | tree
raw | patch | inline | side by side (parent: 8291dce)
raw | patch | inline | side by side (parent: 8291dce)
author | Hamish Coleman <hamish@zot.org> | |
Fri, 17 Feb 2017 05:02:47 +0000 (13:02 +0800) | ||
committer | Hamish Coleman <hamish@zot.org> | |
Fri, 17 Feb 2017 05:02:47 +0000 (13:02 +0800) |
src/oping.c | patch | blob | history |
diff --git a/src/oping.c b/src/oping.c
index b4999c5c11f7e9aff2a585d02c2a6a25390849c2..d0e9f3344134dd0b01d0ea0ecef1cdb5e5e02ed8 100644 (file)
--- a/src/oping.c
+++ b/src/oping.c
memcpy (ctx->history_by_value, ctx->history_by_time,
sizeof (ctx->history_by_time));
/* Remove impossible values */
for (i = 0; i < ctx->history_size; i++)
if (ctx->history_by_value[i]<0)
ctx->history_by_value[i]=NAN;
{
pingobj_iter_t *iter;
int index;
+ size_t history_size = 0;
if (ping == NULL)
return (EINVAL);
ping_context_t *context;
size_t buffer_size;
+ context = ping_iterator_get_context(iter);
+
+ /* if this is a previously existing host, do not recreate it */
+ if (context != NULL) {
+ history_size = context->history_size;
+ context->index = index++;
+ continue;
+ }
+
context = context_create ();
context->index = index;
+ /* start new hosts at the same graph point as old hosts */
+ context->history_size = history_size;
+ context->history_index = history_size;
+ for (int i = 0; i<history_size; i++) {
+ context->history_by_time[i] = -1;
+ }
+
buffer_size = sizeof (context->host);
ping_iterator_get_info (iter, PING_INFO_HOSTNAME, context->host, &buffer_size);
else if (opt_show_graph > 0)
opt_show_graph++;
}
+ else if (key == 'a')
+ {
+ char host[80];
+
+ wprintw(main_win, "New Host: ");
+ echo();
+ wgetnstr(main_win, host, sizeof(host));
+ noecho();
+
+ if (ping_host_add(ping, host) < 0)
+ {
+ const char *errmsg = ping_get_error (ping);
+
+ wprintw (main_win, "Adding host `%s' failed: %s\n", host, errmsg);
+ }
+ else
+ {
+ int box_height = (opt_show_graph == 0) ? 4 : 5;
+
+ /* make sure old data is still visible */
+ for (int i = 0; i<box_height; i++)
+ wprintw (main_win, "\n");
+
+ need_resize = 1;
+ host_num++;
+ ping_initialize_contexts(ping);
+ }
+ }
}
if (need_resize)
@@
memcpy (ctx->history_by_value, ctx->history_by_time,
sizeof (ctx->history_by_time));
- /* Remove impossible values */
+ /* Remove impossible values caused by adding a new host */
for (i = 0; i < ctx->history_size; i++)
if (ctx->history_by_value[i]<0)